@@ -16,12 +16,21 @@ class bcolors:
     UNDERLINE = '\033[4m'
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
+def accountverifier():
+    result = boto3.client('sts').get_caller_identity().get('Account')
+    if result == "713287746880":
+        print(bcolors.FAIL + "You are running in a wrong account, please configure your account by running 'aws configure'"  + bcolors.ENDC)
+        sys.exit(1)
+
+    # print(bcolors.OKGREEN + "Account is verified %s " % result + bcolors.ENDC)
 def taskchecker():
     REGION="us-east-1"
     DBNAME="django"
     try:
         client = boto3.client('rds', region_name=REGION)
-        response = client.describe_db_instances(DBInstanceIdentifier=DBNAME)
+        response = client.describe_db_instances(
+            DBInstanceIdentifier=DBNAME
+            )
         time.sleep(0.5)
         print(bcolors.OKGREEN + "RDS is created %s " % REGION + bcolors.ENDC)
     except Exception as e:
